@@ -60,6 +60,7 @@ setClass("parnames", representation(
   Egxgk="character", ## E(gx|K=k)
   Egxgxk="character", ## E(gx|X=x,K=k)
   adjmeans="character",
+  adjmeansgk="character",
   AveEffZ="character" ## average effect continuous covariate Z
 )
 )
@@ -87,6 +88,7 @@ setClass("results", representation(
   Egxgxk="data.frame",
   gx="list",
   adjmeans="data.frame",
+  adjmeansgk="data.frame",
   AveEffZ="data.frame",
   condeffects="data.frame"
 )
