@@ -137,7 +137,14 @@ computeResults <- function(obj){
                          se[obj@parnames@adjmeans],
                          tval[obj@parnames@adjmeans])
   names(adjmeans) <- c("Estimate", "SE", "Est./SE")
+
+  ## adjusted means given K=k
+  adjmeansgk <- data.frame(est[obj@parnames@adjmeansgk],
+                           se[obj@parnames@adjmeansgk],
+                           tval[obj@parnames@adjmeansgk])
+  names(adjmeansgk) <- c("Estimate", "SE", "Est./SE")
   
+    
   ## average effect of continuous covariates
   AveEffZ <- data.frame()
   if(obj@input@method == "sem"){
@@ -165,6 +172,7 @@ computeResults <- function(obj){
              Egxgxk=Egxgxk,
              gx=gx,
              adjmeans=adjmeans,
+             adjmeansgk=adjmeansgk,
              AveEffZ=AveEffZ,
              condeffects=data.frame() ## we compute conditional effects later using computeConditionalEffects()
   )
@@ -178,7 +186,7 @@ computeResults <- function(obj){
 
 computeLavaanResults <- function(obj){
 
-  ## lavaan.survey -- complex survey designs
+  ## complex survey designs
   ids <- obj@input@complexsurvey$ids
   weights <- obj@input@complexsurvey$weights
   
@@ -196,32 +204,8 @@ computeLavaanResults <- function(obj){
     m1 <- do.call("sem", sem.args)
     
   }else{ # at least one lavaan.survey argument specified
-    
-    if(requireNamespace("lavaan.survey", quietly = TRUE)){ ## check if lavaan.survey is available
       
-      if(!obj@input@fixed.cell){## currently only works for fixed cell sizes
-        stop("EffectLiteR error: The complex survey functionality currently only works for fixed cell sizes. Please use fixed.cell=TRUE.")
-      }
-      
-      sem.args <- list(model=obj@syntax@model,
-                       group="cell", 
-                       missing=obj@input@missing,
-                       se=obj@input@se,
-                       fixed.x=obj@input@fixed.z,
-                       group.label=obj@input@vlevels$cell, 
-                       data=obj@input@data, 
-                       group.w.free = !obj@input@fixed.cell)
-      sem.args <- c(sem.args, obj@input@method_args)
-      m1 <- do.call("sem", sem.args)
-      
-      survey.design <- survey::svydesign(ids=ids, weights=weights, 
-                                         data=obj@input@data)
-      m1 <- lavaan.survey::lavaan.survey(lavaan.fit=m1, 
-                                         survey.design=survey.design)
-      
-    }else{ ## lavaan.survey not installed
-      
-      warning("EffectLiteR warning: Since lavaan.survey is not installed, the lavaan:sem arguments cluster and sampling.weights are used. Only the first specified cluster variable and/or the first  specified sampling weight are used. Consider specifying these arguments directly in the call to effectLite() instead. They will be passed on to lavaan:sem.")
+      message("EffectLiteR message: Since lavaan.survey is no longer on CRAN, the lavaan:sem arguments cluster and sampling.weights are used instead of the lavaan.survey aruments ids and weights. Only the first specified cluster variable and the first specified sampling weight are used.")
       
       ids <- all.vars(ids)[1]
       if(is.na(ids)){ids <- NULL}
@@ -244,8 +228,6 @@ computeLavaanResults <- function(obj){
       m1 <- do.call("sem", sem.args)
       
     }
-        
-  }
   
   return(m1)
   
@@ -419,7 +401,7 @@ computeStdDevEffectSize <- function(obj, est, m1_sem){
     
     y <- obj@input@data[, obj@input@vnames$y]
     x <- obj@input@data[, obj@input@vnames$x]
-    return(sd(y[x==0]))
+    return(sd(y[x==0], na.rm=TRUE))
     
   }
   
